// -*- C++ -*-
// --------------------------------------------------------------------
// The pool of embedded fonts.
// --------------------------------------------------------------------

#ifndef IPEFONTPOOL_H
#define IPEFONTPOOL_H

#include "ipebase.h"
#include "ipegeo.h"

// --------------------------------------------------------------------

//! A text font.
struct IpeFont {
  //! Ipe supports two types of fonts.
  enum TType { EType1, ETrueType };
  //! The font type.
  TType iType;
  //! The name of this font (e.g. "Times-Roman").
  IpeString iName;     
  //! The font id in the Pdflatex output: /Fxx
  int iLatexNumber;    
  //! The font dictionary in the PDF file.
  IpeString iFontDict;
  //! The font descriptor in the PDF file.
  IpeString iFontDescriptor;
  //! The stream dictionary for the font stream in the PDF file.
  IpeString iStreamDict;
  //! The values of LengthX in the font stream in the PDF file.
  int iLength1, iLength2, iLength3;
  //! The stream data for the font stream in the PDF file.
  IpeBuffer iStreamData;
  //! Is there an explicit encoding for this font?
  bool iHasEncoding;
  //! The encoding of this font. 
  IpeString iEncoding[0x100];
  //! Is this one of the 14 standard fonts?
  bool iStandardFont;
  //! The width of each character in font units.
  int iWidth[0x100];
};

//! A list of fonts used by a IpeDocument.
class IpeFontPool : public std::vector<IpeFont> {
public:
  // nothing new yet
};

// --------------------------------------------------------------------
#endif
